@@ -26,8 +26,19 @@ pub use self::bezier::BezierSurf;
 pub use self::bezier::RatBezierCurve;
 pub use self::bezier::BezierCircle;
 pub use self::bezier::BezierCurveDemo1;
+pub use self::bezier::BezierFactory;
 pub use self::teapot::TEAPOT_PACTHES;
 pub use self::teapot::TEAPOT_VERTICES;
 pub use self::teapot::BezierTeapot;
+pub use self::teacup::TEACUP_PACTHES;
+pub use self::teacup::TEACUP_VERTICES;
+pub use self::teacup::BezierTeacup;
+pub use self::teaspoon::TEASPOON_PACTHES;
+pub use self::teaspoon::TEASPOON_VERTICES;
+pub use self::teaspoon::BezierTeaspoon;
+pub use self::utahdata::read_utah_format;
 mod bezier;
 mod teapot;
+mod teaspoon;
+mod teacup;
+mod utahdata;
